<!DOCTYPE kpartgui>
<kpartgui name="KeysManager" version="33">

<MenuBar>
    <Menu name="managekeys">
        <text>&amp;Keys</text>
        <Action name="key_info"/>
        <Action name="key_server_refresh"/>
        <Action name="key_sign"/>
        <Action name="key_edit"/>
        <Action name="key_gener"/>
        <Separator />
        <Action name="key_export"/>
        <Action name="key_import"/>
        <Action name="add_kab"/>
    </Menu>

    <Menu name="edit">
        <Action name="go_default_key"/>
    </Menu>

    <Menu name="view">
        <text>&amp;View</text>
        <Action name="show_secret"/>
        <Action name="show_long_keyid"/>
        <Action name="hide_disabled"/>
        <Menu name="show_details">
            <text>&amp;Show Details</text>
            <Action name="show_trust"/>
            <Action name="show_expi"/>
            <Action name="show_size"/>
            <Action name="show_creat"/>
        </Menu>
        <Action name="trust_filter_settings" />
        <Action name="photo_settings" />
        <Action name="key_refresh"/>
    </Menu>

    <Menu name="groups">
        <text>&amp;Groups</text>
        <Action name="create_group"/>
        <Action name="edit_group"/>
        <Action name="delete_group"/>
    </Menu>

    <Menu name="file">
        <Action name="key_server"/>
        <Action name="kgpg_editor"/>
    </Menu>

    <Menu name="help">
        <Action name="help_tipofday"/>
        <Action name="gpg_man"/>
    </Menu>
</MenuBar>


<ToolBar name="mainToolBar" position="top">
    <Action name="key_info"/>
    <Action name="key_sign"/>
    <Separator/>
    <Action name="key_import"/>
    <Action name="key_export"/>
    <Action name="key_server"/>
    <Separator/>
    <Action name="search_line"/>
</ToolBar>

<State name="group_selected">
    <enable>
        <Action name="edit_group"/>
        <Action name="delete_group"/>
        <Action name="key_server_refresh"/>
    </enable>

    <disable>
        <Action name="add_kab"/>
        <Action name="create_group"/>
        <Action name="key_info"/>
        <Action name="key_sign"/>
        <Action name="key_edit"/>
        <Action name="key_export"/>
	<Action name="key_sign_uid"/>
    </disable>
</State>

<State name="single_selected">
    <enable>
        <Action name="key_server_refresh"/>
        <Action name="add_kab"/>
        <Action name="key_sign"/>
        <Action name="key_export"/>
        <Action name="key_default"/>
        <Action name="key_edit"/>
        <Action name="key_info"/>
        <Action name="key_importallsign"/>
        <Action name="create_group"/>
    </enable>

    <disable>
        <Action name="edit_group"/>
        <Action name="delete_group"/>
    </disable>
</State>

<State name="multi_selected">
    <enable>
        <Action name="key_server_refresh"/>
        <Action name="key_sign"/>
        <Action name="key_export"/>
        <Action name="key_importallsign"/>
        <Action name="create_group"/>
    </enable>

    <disable>
        <Action name="add_kab"/>
        <Action name="edit_group"/>
        <Action name="delete_group"/>
        <Action name="key_default"/>
        <Action name="key_edit"/>
        <Action name="key_info"/>
    </disable>
</State>

<State name="empty_list">
  <disable>
    <Action name="edit_group"/>
    <Action name="delete_group"/>
    <Action name="key_default"/>
    <Action name="key_edit"/>
    <Action name="key_info"/>
    <Action name="key_importallsign"/>
    <Action name="key_server_refresh"/>
    <Action name="key_sign"/>
    <Action name="key_export"/>
    <Action name="create_group"/>
    <Action name="add_kab"/>
    <Action name="key_sign_uid"/>
  </disable>
</State>

</kpartgui>
