
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libkastencontrollers.so.4 )
( cd usr/lib ; ln -sf libkastencontrollers.so.4.4.0 libkastencontrollers.so.4 )
( cd usr/lib ; rm -rf liboktetakastengui.so )
( cd usr/lib ; ln -sf liboktetakastengui.so.4 liboktetakastengui.so )
( cd usr/lib ; rm -rf liboktetakastencore.so )
( cd usr/lib ; ln -sf liboktetakastencore.so.4 liboktetakastencore.so )
( cd usr/lib ; rm -rf libsuperkaramba.so )
( cd usr/lib ; ln -sf libsuperkaramba.so.4 libsuperkaramba.so )
( cd usr/lib ; rm -rf libkastengui.so.4 )
( cd usr/lib ; ln -sf libkastengui.so.4.4.0 libkastengui.so.4 )
( cd usr/lib ; rm -rf liboktetagui.so )
( cd usr/lib ; ln -sf liboktetagui.so.4 liboktetagui.so )
( cd usr/lib ; rm -rf libkdelirc_shared.so.1 )
( cd usr/lib ; ln -sf libkdelirc_shared.so.1.0.0 libkdelirc_shared.so.1 )
( cd usr/lib ; rm -rf libkastencore.so )
( cd usr/lib ; ln -sf libkastencore.so.4 libkastencore.so )
( cd usr/lib ; rm -rf liboktetakastencontrollers.so.4 )
( cd usr/lib ; ln -sf liboktetakastencontrollers.so.4.4.0 liboktetakastencontrollers.so.4 )
( cd usr/lib ; rm -rf liboktetacore.so.4 )
( cd usr/lib ; ln -sf liboktetacore.so.4.4.0 liboktetacore.so.4 )
( cd usr/lib ; rm -rf liboktetacore.so )
( cd usr/lib ; ln -sf liboktetacore.so.4 liboktetacore.so )
( cd usr/lib ; rm -rf libkerfuffle.so )
( cd usr/lib ; ln -sf libkerfuffle.so.4 libkerfuffle.so )
( cd usr/lib ; rm -rf libkdelirc_shared.so )
( cd usr/lib ; ln -sf libkdelirc_shared.so.1 libkdelirc_shared.so )
( cd usr/lib ; rm -rf liboktetakastencore.so.4 )
( cd usr/lib ; ln -sf liboktetakastencore.so.4.4.0 liboktetakastencore.so.4 )
( cd usr/lib ; rm -rf libkerfuffle.so.4 )
( cd usr/lib ; ln -sf libkerfuffle.so.4.4.0 libkerfuffle.so.4 )
( cd usr/lib ; rm -rf liboktetakastencontrollers.so )
( cd usr/lib ; ln -sf liboktetakastencontrollers.so.4 liboktetakastencontrollers.so )
( cd usr/lib ; rm -rf liboktetakastengui.so.4 )
( cd usr/lib ; ln -sf liboktetakastengui.so.4.4.0 liboktetakastengui.so.4 )
( cd usr/lib ; rm -rf libsuperkaramba.so.4 )
( cd usr/lib ; ln -sf libsuperkaramba.so.4.4.0 libsuperkaramba.so.4 )
( cd usr/lib ; rm -rf libkastencontrollers.so )
( cd usr/lib ; ln -sf libkastencontrollers.so.4 libkastencontrollers.so )
( cd usr/lib ; rm -rf libkastencore.so.4 )
( cd usr/lib ; ln -sf libkastencore.so.4.4.0 libkastencore.so.4 )
( cd usr/lib ; rm -rf libkastengui.so )
( cd usr/lib ; ln -sf libkastengui.so.4 libkastengui.so )
( cd usr/lib ; rm -rf liboktetagui.so.4 )
( cd usr/lib ; ln -sf liboktetagui.so.4.4.0 liboktetagui.so.4 )
( cd usr/share/doc/HTML/en/kfloppy ; rm -rf common )
( cd usr/share/doc/HTML/en/kfloppy ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/superkaramba ; rm -rf common )
( cd usr/share/doc/HTML/en/superkaramba ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ark ; rm -rf common )
( cd usr/share/doc/HTML/en/ark ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kwallet ; rm -rf common )
( cd usr/share/doc/HTML/en/kwallet ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ktimer ; rm -rf common )
( cd usr/share/doc/HTML/en/ktimer ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/blockdevices ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/blockdevices ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/irkick ; rm -rf common )
( cd usr/share/doc/HTML/en/irkick ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcalc ; rm -rf common )
( cd usr/share/doc/HTML/en/kcalc ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/printer-applet ; rm -rf common )
( cd usr/share/doc/HTML/en/printer-applet ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kgpg ; rm -rf common )
( cd usr/share/doc/HTML/en/kgpg ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcmlirc ; rm -rf common )
( cd usr/share/doc/HTML/en/kcmlirc ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcharselect ; rm -rf common )
( cd usr/share/doc/HTML/en/kcharselect ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdf ; rm -rf common )
( cd usr/share/doc/HTML/en/kdf ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/okteta ; rm -rf common )
( cd usr/share/doc/HTML/en/okteta ; ln -sf /usr/share/doc/HTML/en/common common )
