<!DOCTYPE kpartgui>
<kpartgui name="kwalleteditor" version="2">
  <MenuBar>
    <Menu name="file"><text>&amp;File</text>
      <Action name="create_folder"/>
      <Action name="delete_folder"/>
      <Separator/>
      <Action name="change_password"/>
      <Separator/>
      <Action name="merge"/>
      <Action name="import"/>
      <Action name="export"/>
    </Menu>
    <Menu name="help"><text>&amp;Help</text>
    </Menu>
  </MenuBar>
</kpartgui>
