<!DOCTYPE kpartgui>
<kpartgui name="ark_part" version="1">
<MenuBar>
	<Menu name="file">
		<text>&amp;File</text>
		<Action name="file_save_as" group="file_save"/>
	</Menu>
	<Menu name="action">
		<text>&amp;Action</text>
		<Action name="add"/>
		<Action name="add-dir"/>
		<Action name="delete"/>
		<Action name="extract"/>
		<Action name="preview"/>
	</Menu>
	<Menu name="settings">
		<text>&amp;Settings</text>
		<Action name="show-infopanel" group="settings_show"/>
	</Menu>
</MenuBar>
<ToolBar name="mainToolBar">
	<Action name="add"/>
	<Action name="add-dir"/>
	<Action name="delete"/>
	<Action name="extract"/>
	<Action name="preview"/>
</ToolBar>
</kpartgui>
